@@ -13,8 +13,7 @@ use MediaWiki\Logger\LoggerFactory;
  * Abstract base class with static methods for rendering the <math> tags using
  * different technologies. These static methods create a new instance of the
  * extending classes and render the math tags based on the mode setting of the user.
- * Furthermore this class handles the caching of the rendered output and provides
- * debug information, if run in mathdebug mode.
+ * Furthermore this class handles the caching of the rendered output.
  *
  * @author Tomasz Wegrzanowski
  * @author Brion Vibber
@@ -32,22 +31,13 @@ abstract class MathRenderer {
 	/** @var string the original user input string (which was used to calculate the inputhash) */
 	protected $userInputTex = '';
 	// FURTHER PROPERTIES OF THE MATHEMATICAL CONTENT
-	/** @var (MW_MATHSTYLE_INLINE_DISPLAYSTYLE|MW_MATHSTYLE_DISPLAY|MW_MATHSTYLE_INLINE) the rendering style */
-	protected $mathStyle = MW_MATHSTYLE_INLINE_DISPLAYSTYLE;
+	/** @var ('inlineDisplaystyle'|'display'|'inline'|'linebreak') the rendering style */
+	protected $mathStyle = 'inlineDisplaystyle';
 	/** @var array with userdefined parameters passed to the extension (not used) */
 	protected $params = array();
 	/** @var string a userdefined identifier to link to the equation. */
 	protected $id = '';
 
-	// DEBUG VARIABLES
-	// Available, if Math extension runs in debug mode ($wgMathDebug = true) only.
-	/** @var int LaTeXML return code (will be available in future Mathoid versions as well) */
-	protected $statusCode = 0;
-	/** @var timestamp of the last modification of the database entry */
-	protected $timestamp;
-	/** @var log messages generated during conversion of mathematical content */
-	protected $log = '';
-
 	// STATE OF THE CLASS INSTANCE
 	/** @var boolean has variable tex been security-checked */
 	protected $texSecure = false;
@@ -61,10 +51,10 @@ abstract class MathRenderer {
 	protected $lastError = '';
 	/** @var string md5 value from userInputTex */
 	protected $md5 = '';
-	/** @var binary packed inputhash */
+	/** @var string binary packed inputhash */
 	protected $inputHash = '';
-	/** @var int rendering mode MW_MATH_(PNG|MATHML|SOURCE...) */
-	protected $mode = MW_MATH_PNG;
+	/** @var string rendering mode */
+	protected $mode = 'png';
 
 	/**
 	 * Constructs a base MathRenderer
@@ -73,12 +63,35 @@ abstract class MathRenderer {
 	 * @param array $params (optional) HTML attributes
 	 */
 	public function __construct( $tex = '', $params = array() ) {
-		$this->userInputTex = $tex;
-		$this->tex = $tex;
 		$this->params = $params;
 		if ( isset( $params['id'] ) ) {
 			$this->id = $params['id'];
 		}
+		if ( isset( $params['display'] ) ) {
+			$layoutMode = $params['display'];
+			if ( $layoutMode == 'block' ) {
+				$this->mathStyle = 'display';
+				$tex = '{\displaystyle ' . $tex . '}';
+			} elseif ( $layoutMode == 'inline' ) {
+				$this->mathStyle = 'inline';
+				$tex = '{\textstyle ' . $tex . '}';
+			} elseif ( $layoutMode == 'linebreak' ) {
+				$this->mathStyle = 'linebreak';
+				$tex = '\[ ' . $tex . ' \]';
+			}
+		}
+		// TODO: Implement caching for attributes of the math tag
+		// Currently the key for the database entry relating to an equation
+		// is md5($tex) the new option to determine if the tex input
+		// is rendered in displaystyle or textstyle would require a database
+		// layout change to use a composite key e.g. (md5($tex),$mathStyle).
+		// As a workaround we use the prefix \displaystyle so that the key becomes
+		// md5((\{\\displaystyle|\{\\textstyle)?\s?$tex\}?)
+		// The new value of $tex string describes now how the rendering should look like.
+		// The variable MathRenderer::mathStyle determines if the rendered equation should
+		// be centered in a new line, or just in be displayed in the current line.
+		$this->userInputTex = $tex;
+		$this->tex = $tex;
 	}
 
 	/**
@@ -86,10 +99,10 @@ abstract class MathRenderer {
 	 *
 	 * @param string $tex LaTeX markup
 	 * @param array $params HTML attributes
-	 * @param int $mode constant indicating rendering mode
+	 * @param string $mode constant indicating rendering mode
 	 * @return string HTML for math tag
 	 */
-	public static function renderMath( $tex, $params = array(), $mode = MW_MATH_PNG ) {
+	public static function renderMath( $tex, $params = array(), $mode = 'png' ) {
 		$renderer = self::getRenderer( $tex, $params, $mode );
 		if ( $renderer->render() ) {
 			return $renderer->getHtmlOutput();
@@ -117,65 +130,42 @@ abstract class MathRenderer {
 	 *
 	 * @param string $tex LaTeX markup
 	 * @param array $params HTML attributes
-	 * @param int $mode constant indicating rendering mode
+	 * @param string $mode indicating rendering mode
 	 * @return MathRenderer appropriate renderer for mode
 	 */
-	public static function getRenderer( $tex, $params = array(), $mode = MW_MATH_PNG ) {
-		global $wgDefaultUserOptions, $wgMathValidModes, $wgMathEnableExperimentalInputFormats;
-		$mathStyle = null;
-		if ( isset( $params['display'] ) ) {
-			$layoutMode = $params['display'];
-			if ( $layoutMode == 'block' ) {
-				$mathStyle = MW_MATHSTYLE_DISPLAY;
-				// TODO: Implement caching for attributes of the math tag
-				// Currently the key for the database entry relating to an equation
-				// is md5($tex) the new option to determine if the tex input
-				// is rendered in displaystyle or textstyle would require a database
-				// layout change to use a composite key e.g. (md5($tex),$mathStyle).
-				// As a workaround we use the prefix \displaystyle so that the key becomes
-				// md5((\{\\displaystyle|\{\\textstyle)?\s?$tex\}?)
-				// The new value of $tex string describes now how the rendering should look like.
-				// The variable MathRenderer::mathStyle determines if the rendered equation should
-				// be centered in a new line, or just in be displayed in the current line.
-				$tex = '{\displaystyle ' . $tex . '}';
-			} elseif ( $layoutMode == 'inline' ) {
-				$mathStyle = MW_MATHSTYLE_INLINE;
-				$tex = '{\textstyle ' . $tex . '}';
-			}
-		}
+	public static function getRenderer( $tex, $params = array(), $mode = 'png' ) {
+		global $wgDefaultUserOptions, $wgMathEnableExperimentalInputFormats;
 
 		if ( isset( $params['forcemathmode'] ) ) {
 			$mode = $params['forcemathmode'];
 		}
-		if ( !in_array( $mode, $wgMathValidModes ) ) {
+		if ( !in_array( $mode, self::getValidModes() ) ) {
 			$mode = $wgDefaultUserOptions['math'];
 		}
-		if ( $wgMathEnableExperimentalInputFormats === true && $mode == MW_MATH_MATHML &&
+		if ( $wgMathEnableExperimentalInputFormats === true && $mode == 'mathml' &&
 			 isset( $params['type'] ) ) {
 			// Support of MathML input (experimental)
-			// Currently support for mode MW_MATH_MATHML only
+			// Currently support for mode 'mathml' only
 			if ( !in_array( $params['type'], array( 'pmml', 'ascii' ) ) ) {
 				unset( $params['type'] );
 			}
 		}
 		switch ( $mode ) {
-			case MW_MATH_MATHJAX:
-			case MW_MATH_SOURCE:
+			case 'source':
 				$renderer = new MathSource( $tex, $params );
 				break;
-			case MW_MATH_PNG:
+			case 'png':
 				$renderer = new MathTexvc( $tex, $params );
 				break;
-			case MW_MATH_LATEXML:
+			case 'latexml':
 				$renderer = new MathLaTeXML( $tex, $params );
 				break;
-			case MW_MATH_MATHML:
+			case 'mathml':
 			default:
 				$renderer = new MathMathML( $tex, $params );
 		}
 		LoggerFactory::getInstance( 'Math' )->info( 'Start rendering $' . $renderer->tex .
 			'$ in mode ' . $mode );
-		$renderer->setMathStyle( $mathStyle );
 		return $renderer;
 	}
 
@@ -247,7 +237,7 @@ abstract class MathRenderer {
 
 	/**
 	 * Decode binary packed hash from the database to md5 of input_tex
-	 * @param binary $hash
+	 * @param string $hash (binary)
 	 * @return string md5
 	 */
 	private static function dbHash2md5( $hash ) {
@@ -262,9 +252,7 @@ abstract class MathRenderer {
 	 * @return boolean true if read successfully, false otherwise
 	 */
 	public function readFromDatabase() {
-		/** @var DatabaseBase */
 		$dbr = wfGetDB( DB_SLAVE );
-		/** @var ResultWrapper */
 		$rpage = $dbr->selectRow( $this->getMathTableName(),
 			$this->dbInArray(),
 			array( 'math_inputhash' => $this->getInputHash() ),
@@ -279,6 +267,7 @@ abstract class MathRenderer {
 			return false;
 		}
 	}
+
 	/**
 	 * @return array with the database column names
 	 */
@@ -294,7 +283,7 @@ abstract class MathRenderer {
 
 	/**
 	 * Reads the values from the database but does not overwrite set values with empty values
-	 * @param database_row $rpage
+	 * @param stdClass $rpage (a database row)
 	 */
 	protected function initializeFromDatabaseRow( $rpage ) {
 		$this->inputHash = $rpage->math_inputhash; // MUST NOT BE NULL
@@ -325,7 +314,6 @@ abstract class MathRenderer {
 	 * @param DatabaseBase $dbw
 	 */
 	public function writeToDatabase( $dbw = null ) {
-		global $wgMathDebug;
 		# Now save it back to the DB:
 		if ( !wfReadOnly() ) {
 			$dbw = $dbw ?: wfGetDB( DB_MASTER );
@@ -347,18 +335,16 @@ abstract class MathRenderer {
 				} );
 			} else {
 				$dbw->onTransactionIdle( function () use (
-					$dbw, $outArray, $wgMathDebug, $method, $mathTableName
+					$dbw, $outArray, $method, $mathTableName
 				) {
 					$dbw->insert( $mathTableName, $outArray, $method, array( 'IGNORE' ) );
-					if ( $wgMathDebug ) {
-						LoggerFactory::getInstance( 'Math' )->debug(
-							'Row inserted after db transaction was idle ' .
-							var_export( $outArray, true ) . " to database" );
-						if ( $dbw->affectedRows() == 0 ) {
-							// That's the price for the delayed update.
-							LoggerFactory::getInstance( 'Math' )->warning(
-								'Entry could not be written. Might be changed in between.' );
-						}
+					LoggerFactory::getInstance( 'Math' )->debug(
+						'Row inserted after db transaction was idle ' .
+						var_export( $outArray, true ) . " to database" );
+					if ( $dbw->affectedRows() == 0 ) {
+						// That's the price for the delayed update.
+						LoggerFactory::getInstance( 'Math' )->warning(
+							'Entry could not be written. Might be changed in between.' );
 					}
 				} );
 			}
@@ -421,17 +407,9 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 * gets the timestamp, of the last rendering of that equation
-	 * @return int
-	 */
-	public function getTimestamp() {
-		return $this->timestamp;
-	}
-
-	/**
-	 * gets the rendering mode MW_MATH_*
+	 * Gets the rendering mode
 	 *
-	 * @return int
+	 * @return string
 	 */
 	public function getMode() {
 		return $this->mode;
@@ -439,12 +417,11 @@ abstract class MathRenderer {
 
 	/**
 	 * Sets the rendering mode
-	 * @param int $newMode element of the array $wgMathValidModes
+	 * @param string $newMode element of the array $wgMathValidModes
 	 * @return bool
 	 */
 	public function setMode( $newMode ) {
-		global $wgMathValidModes;
-		if ( in_array( $newMode, $wgMathValidModes ) ) {
+		if ( in_array( $newMode, self::getValidModes() ) ) {
 			$this->mode = $newMode;
 			return true;
 		} else {
@@ -549,53 +526,25 @@ abstract class MathRenderer {
 		return $this->lastError;
 	}
 
-	/**
-	 * @return string
-	 */
-	public function getLog() {
-		return $this->log;
-	}
-
 	/**
 	 *
-	 * @param (MW_MATHSTYLE_INLINE_DISPLAYSTYLE|MW_MATHSTYLE_DISPLAY|MW_MATHSTYLE_INLINE) $mathStyle
+	 * @param string $mathStyle ('inlineDisplaystyle'|'display'|'inline')
 	 */
-	public function setMathStyle( $displayStyle = MW_MATHSTYLE_DISPLAY ) {
-		if ( $this->mathStyle !== $displayStyle ){
+	public function setMathStyle( $mathStyle = 'display' ) {
+		if ( $this->mathStyle !== $mathStyle ){
 			$this->changed = true;
 		}
-		$this->mathStyle = $displayStyle;
+		$this->mathStyle = $mathStyle;
 	}
 
 	/**
 	 * Returns the value of the DisplayStyle attribute
-	 * @return (MW_MATHSTYLE_INLINE_DISPLAYSTYLE|MW_MATHSTYLE_DISPLAY|MW_MATHSTYLE_INLINE) the DisplayStyle
+	 * @return string ('inlineDisplaystyle'|'display'|'inline'|'linebreak') the DisplayStyle
 	 */
 	public function getMathStyle() {
 		return $this->mathStyle;
 	}
-	/**
-	 * @param string $log
-	 */
-	public function setLog( $log ) {
-		$this->changed = true;
-		$this->log = $log;
-	}
 
-	/**
-	 * @return int
-	 */
-	public function getStatusCode() {
-		return $this->statusCode;
-	}
-
-	/**
-	 * @param unknown_type $statusCode
-	 */
-	public function setStatusCode( $statusCode ) {
-		$this->changed = true;
-		$this->statusCode = $statusCode;
-	}
 	/**
 	 * Get if the input tex was marked as secure
 	 * @return boolean
@@ -609,12 +558,11 @@ abstract class MathRenderer {
 	 * @return bool
 	 */
 	public function checkTex() {
-		global $wgMathDisableTexFilter;
-		if ( $this->texSecure || (int) $wgMathDisableTexFilter == MW_MATH_CHECK_NEVER ) {
+		if ( $this->texSecure || self::getDisableTexFilter() == 'never' ) {
 			// equation was already checked or checking is disabled
 			return true;
 		} else {
-			if( (int) $wgMathDisableTexFilter == MW_MATH_CHECK_NEW && $this->mode != MW_MATH_SOURCE ){
+			if( self::getDisableTexFilter() == 'new' && $this->mode != 'source' ){
 				if( $this->readFromDatabase() ){
 					return true;
 				}
@@ -631,8 +579,6 @@ abstract class MathRenderer {
 		}
 	}
 
-
-
 	public function isInDatabase() {
 		if ( $this->storedInDatabase === null ) {
 			$this->readFromDatabase();
@@ -649,7 +595,7 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 * @return string Userdefined ID
+	 * @return string user defined ID
 	 */
 	public function getID() {
 		return $this->id;
@@ -667,7 +613,7 @@ abstract class MathRenderer {
 
 	/**
 	 *
-	 * @param type $svg
+	 * @param string $svg
 	 */
 	public function setSvg( $svg ) {
 		$this->changed = true;
@@ -684,7 +630,7 @@ abstract class MathRenderer {
 	 *
 	 * @return string XML-Document of the rendered SVG
 	 */
-	public function getSvg( $render = 'render' ) {
+	public function getSvg( /** @noinspection PhpUnusedParameterInspection */ $render = 'render' ) {
 		// Spaces will prevent the image from being displayed correctly in the browser
 		return trim( $this->svg );
 	}
@@ -696,4 +642,14 @@ abstract class MathRenderer {
 		return $names[ $this->getMode() ];
 	}
 
+	public static function getValidModes(){
+		global $wgMathValidModes;
+		return array_map( "MathHooks::mathModeToString", $wgMathValidModes );
+	}
+
+
+	public static function getDisableTexFilter(){
+		global $wgMathDisableTexFilter;
+		return MathHooks::mathCheckToString( $wgMathDisableTexFilter );
+	}
 }
